@@ -7,7 +7,7 @@
 #####################################################################################
 
 package App::Monupco::dotCloud;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 our $NAME = "monupco-dotcloud-perl";
 
 use App::Monupco::dotCloud::Parser;
@@ -27,10 +27,10 @@ my $dotcloud_env = decode_json( $json_text );
 
 my $data = {
     'user_id'    => $ENV{'MONUPCO_USER_ID'},
-    'app_name'   => $dotcloud_env{'DOTCLOUD_PROJECT'} + "." + $dotcloud_env{'DOTCLOUD_SERVICE_NAME'},
-    'app_uuid'   => $dotcloud_env{'DOTCLOUD_WWW_HTTP_HOST'},
+    'app_name'   => $dotcloud_env->{'DOTCLOUD_PROJECT'}.".".$dotcloud_env->{'DOTCLOUD_SERVICE_NAME'},
+    'app_uuid'   => $dotcloud_env->{'DOTCLOUD_WWW_HTTP_HOST'},
     'app_type'   => "perl",
-    'app_url'    => $dotcloud_env{'DOTCLOUD_WWW_HTTP_URL'},
+    'app_url'    => $dotcloud_env->{'DOTCLOUD_WWW_HTTP_URL'},
     'app_vendor' => 1,   # dotCloud
     'pkg_type'   => 400, # Perl / CPAN
     'installed'  => [],
